==> handyman_updated_files11.5.0.zip: handyman_updated_files11.5.0/resources/lang/es/landingpage.php <==
<?php

return [
    'home' => 'Inicio',
    'categories' => 'Categorías',
    'services' => 'Servicios',
    'blogs' => 'Blogs',
    'providers' => 'Proveedores',
    'bookings' => 'Reservas',
    'post_jobs' => 'Publicar Trabajo',
    'previous' => 'Anterior',
    'next' => 'Siguiente',
    'post' => 'Publicar',
    'no_previous_post' => 'No Hay Publicaciones Anteriores',
    'no_next_post' => 'No Hay Publicaciones Siguientes',
    'about_provider' => 'Acerca del Proveedor',
    'service_total_time' => 'Tiempo Total del Servicio',
    'check_status' => 'Verificar Estado',
    'Add-ons' => 'Complementos',
    'about_handyman' => 'Acerca del Manitas',
    'rate_handyman' => 'Calificar Manitas',
    'price_detail' => 'Detalle de Precio',
    'subtotal' => 'Subtotal',
    'total' => 'Total',
    'total_extra_charges' => 'Total de Cargos Extra',
    'coupon' => 'Cupón',
    'tax' => 'Impuesto',
    'on_basis' => 'Basado en 00:01 min',
    'extra_charges' => 'Cargos Extra',
    'payment_detail' => 'Detalle de Pago',
    'id' => 'ID',
    'transaction_id' => 'ID de Transacción',
    'request_invoice' => 'Solicitar Factura',
    'your_review' => 'Tu Opinión',
    'your_rating' => 'Tu Puntuación',
    'review_for' => 'Opinión Para',
    'forgot_title' => 'Bienvenido a Nuestro Servicio de Manitas',
    'forgot_description' => 'Servicios de manitas calificados como reparación, arreglo y mejora de su espacio con experiencia, haciendo la vida más fácil, un proyecto a la vez.',
    'email' => 'Correo Electrónico',
    'overall_rating' => 'Puntuación General',
    'your' => 'Tu',
    'remember_me' => 'Recuérdame',
    'handyman_provider_register' => '¿Quieres registrarte como proveedor o manitas?',
    'demo_accounts' => 'Cuentas de Demostración',
    'admin' => 'Administrador',
    'provider' => 'Proveedor',
    'handyman' => 'Manitas',
    'user' => 'Usuario',
    'booking_history' => 'Historial de Reservas',
    'why_choose_me' => '¿Por Qué Elegirme?',
    'projects' => 'Proyectos',
    'satisfy_customers' => 'Satisfacer Clientes',
    'project_completed' => 'Proyectos Completados',
    'provider_personal_info' => 'Información Personal del Proveedor',
    'member_since' => 'Miembro Desde',
    'languages' => 'Idiomas',
    'training' => 'Entrenamiento',
    'why_choose_me_title' => 'Por qué elegirme como tu proveedor de servicios de confianza',
    'user_name' => 'Nombre de Usuario',
    'minutes' => 'Minutos',
    'created_by' => 'Creado Por',
    'about_service' => 'Acerca de los Servicios',
    'about_provider' => 'Acerca del Proveedor',
    'complet_project' => 'Proyecto Completado',
    'msg_complete_project' => 'Proyecto Completo Hasta Ahora',
    'order_detail' => 'Detalle de Pedido',
    'select_service_package' => 'Seleccionar Servicio o Paquete',
    'any_question' => '¿Alguna Pregunta?',
    'related_services' => 'Servicios Relacionados',
    'read_more' => 'Leer Más',
    'read_less' => 'Leer Menos',
    'add_to_wishlist' => 'Agregar a la Lista de Deseos',
    'share_this_service' => 'Compartir Este Servicio',
    'copy_link' => 'Copiar Enlace',
    'business_inquries' => 'Consultas Empresariales',
    'helpline_number' => 'Número de Ayuda',
    'facebook' => 'Facebook',
    'twitter' => 'Twitter',
    'instagram' => 'Instagram',
    'youtube' => 'YouTube',
    'advance_payment' => 'Pago Anticipado',
    'off' => 'Descuento',
    'handyman_personal_info' => 'Información Personal del Manitas',
    'search' => 'Buscar',
    'select' => 'Seleccionar',
    'schedule_service' => 'Programar Servicio',
    'remove' => 'Eliminar',
    'date_time' => 'Fecha y Hora',
    'available_slots' => 'Espacios Disponibles',
    'slot_not_available' => 'Espacio No Disponible',
    'quantity' => 'Cantidad',
    'remove_coupon' => 'Eliminar Cupón',
    'pay_advance' => 'Pagar Anticipo',
    'save_booking' => 'Guardar Reserva',
    'edit_your_review' => 'Editar Tu Opinión',
    'delete' => 'Eliminar',
    'all_categories' => 'Todas las Categorías',
    'all_providers' => 'Todos los Proveedores',
    'all_price' => 'Todos los Precios',
    'sort_by' => 'Ordenar Por',
    'best_selling' => 'Más Vendidos',
    'top_rated' => 'Más Valorados',
    'newest' => 'Más Recientes',
    'refresh' => 'Actualizar',
    'booking_detail' => 'Detalle de la Reserva',
    'exp' => 'Exp',
    'applied' => 'Aplicado',
    'current_location' => 'Ubicación Actual',
    'record_not_found' => 'Registro No Encontrado',
    'get_nearest_services' => 'Obtener Servicios Más Cercanos',
    'continue_view_services' => '¿Continuar viendo los servicios disponibles de TODAS las áreas?',
    'discover_find_services' => 'Descubre y encuentra servicios disponibles en tu área actual.',
    'off_location' => 'Fuera de la Ubicación',
    'post_job_service' => 'Servicio de Publicación de Trabajo',
    'add_your_service' => 'Agregar Tu Servicio',
    'add_service_page_msg' => 'Agrega ese servicio que no puedes encontrar en nuestros servicios.',
    'Service_Category' => 'Categoría del Servicio',
    'select_category' => 'Selecciona una categoría',
    'loading_categories' => 'Cargando categorías',
    'service_name' => 'Nombre del Servicio',
    'Type' => 'Tipo',
    'advance_payment_option' => 'Opción de Pago Anticipado',
    'Proceed_To_Payment' => 'Proceder al Pago',
    'min' => 'Min',
    'services_booked' => 'Servicios Reservados',
    'subscribe_msg' => 'Gracias por suscribirte',
    'pay_now' => 'Pagar Ahora',
    'our_clients' => 'Nuestros Clientes',
    'hrs' => 'hrs',
    'reset' => 'Reiniciar',
    'cancel_booking' => 'Cancelar Reserva',
    'payment_option' => 'Opción de Pago',
    'include_package' => 'Incluido en Este Paquete',
    'start' => 'Comenzar',
    'hold' => 'Mantener',
    'done' => 'Hecho',
    'resume' => 'Reanudar',
    'cancel' => 'Cancelar',
    'reason' => 'Motivo',
    'waiting_for_response' => 'Esperando Respuesta',
    'reason_modal_msg' => '¿Estás seguro de que deseas mantener este servicio?',
    'cancel_modal_msg' => 'Por favor, da una razón para cancelar esta reserva',
    'job_request' => 'Solicitud de Trabajo',
    'near_by_location' => 'Ubicación Cercana',
    'handyman_category' => 'Categoría de Manitas',
    'popular_services' => 'Servicios Populares',
    'terms_conditions' => 'Términos y Condiciones',
    'privacy_policy' => 'Política de Privacidad',
    'accept_all' => '¡Aceptar Todo!',
    'reviews_for' => 'Opiniones Para',
    'min_read' => 'Lectura Min',
    'available_days' => 'Días Disponibles',
    'available_location' => 'Ubicación Disponible',
    'all' => 'Todos',
    'view_more' => 'Ver Más',
    'location' => 'Ubicación',
    'slot_not_available' => 'Ranura no disponible',
    'get_current_location' => 'Obtener ubicación actual',
    'data_deletion_request' => 'Deletation Request',
];

==> handyman_updated_files11.11.0.zip: handyman_updated_files11.11.0/resources/lang/es/landingpage.php <==
<?php

return [
    'home' => 'Inicio',
    'categories' => 'Categorías',
    'services' => 'Servicios',
    'blogs' => 'Blogs',
    'providers' => 'Proveedores',
    'bookings' => 'Reservas',
    'post_jobs' => 'Publicar Trabajo',
    'previous' => 'Anterior',
    'next' => 'Siguiente',
    'post' => 'Publicar',
    'no_previous_post' => 'No Hay Publicaciones Anteriores',
    'no_next_post' => 'No Hay Publicaciones Siguientes',
    'about_provider' => 'Acerca del Proveedor',
    'service_total_time' => 'Tiempo Total del Servicio',
    'check_status' => 'Verificar Estado',
    'Add-ons' => 'Complementos',
    'about_handyman' => 'Acerca del Manitas',
    'rate_handyman' => 'Calificar Manitas',
    'price_detail' => 'Detalle de Precio',
    'subtotal' => 'Subtotal',
    'total' => 'Total',
    'total_extra_charges' => 'Total de Cargos Extra',
    'coupon' => 'Cupón',
    'tax' => 'Impuesto',
    'on_basis' => 'Basado en 00:01 min',
    'extra_charges' => 'Cargos Extra',
    'payment_detail' => 'Detalle de Pago',
    'id' => 'ID',
    'transaction_id' => 'ID de Transacción',
    'request_invoice' => 'Solicitar Factura',
    'your_review' => 'Tu Opinión',
    'your_rating' => 'Tu Puntuación',
    'review_for' => 'Opinión Para',
    'forgot_title' => 'Bienvenido a Nuestro Servicio de Manitas',
    'forgot_description' => 'Servicios de manitas calificados como reparación, arreglo y mejora de su espacio con experiencia, haciendo la vida más fácil, un proyecto a la vez.',
    'email' => 'Correo Electrónico',
    'overall_rating' => 'Puntuación General',
    'your' => 'Tu',
    'remember_me' => 'Recuérdame',
    'handyman_provider_register' => '¿Quieres registrarte como proveedor o manitas?',
    'demo_accounts' => 'Cuentas de Demostración',
    'admin' => 'Administrador',
    'provider' => 'Proveedor',
    'handyman' => 'Manitas',
    'user' => 'Usuario',
    'booking_history' => 'Historial de Reservas',
    'why_choose_me' => '¿Por Qué Elegirme?',
    'projects' => 'Proyectos',
    'satisfy_customers' => 'Satisfacer Clientes',
    'project_completed' => 'Reservas completadas',
    'provider_personal_info' => 'Información Personal del Proveedor',
    'member_since' => 'Miembro Desde',
    'languages' => 'Idiomas',
    'training' => 'Entrenamiento',
    'why_choose_me_title' => 'Por qué elegirme como tu proveedor de servicios de confianza',
    'user_name' => 'Nombre de Usuario',
    'minutes' => 'Minutos',
    'created_by' => 'Creado Por',
    'about_service' => 'Acerca de los Servicios',
    'about_provider' => 'Acerca del Proveedor',
    'complet_project' => 'Proyecto Completado',
    'msg_complete_project' => 'Proyecto Completo Hasta Ahora',
    'order_detail' => 'Detalle de Pedido',
    'select_service_package' => 'Seleccionar Servicio o Paquete',
    'any_question' => '¿Alguna Pregunta?',
    'related_services' => 'Servicios Relacionados',
    'read_more' => 'Leer Más',
    'read_less' => 'Leer Menos',
    'add_to_wishlist' => 'Agregar a la Lista de Deseos',
    'share_this_service' => 'Compartir Este Servicio',
    'copy_link' => 'Copiar Enlace',
    'business_inquries' => 'Consultas Empresariales',
    'helpline_number' => 'Número de Ayuda',
    'facebook' => 'Facebook',
    'twitter' => 'Twitter',
    'instagram' => 'Instagram',
    'youtube' => 'YouTube',
    'advance_payment' => 'Pago Anticipado',
    'off' => 'Descuento',
    'handyman_personal_info' => 'Información Personal del Manitas',
    'search' => 'Buscar',
    'select' => 'Seleccionar',
    'schedule_service' => 'Programar Servicio',
    'remove' => 'Eliminar',
    'date_time' => 'Fecha y Hora',
    'available_slots' => 'Espacios Disponibles',
    'slot_not_available' => 'Espacio No Disponible',
    'quantity' => 'Cantidad',
    'remove_coupon' => 'Eliminar Cupón',
    'pay_advance' => 'Pagar Anticipo',
    'save_booking' => 'Guardar Reserva',
    'edit_your_review' => 'Editar Tu Opinión',
    'delete' => 'Eliminar',
    'all_categories' => 'Todas las Categorías',
    'all_providers' => 'Todos los Proveedores',
    'all_price' => 'Todos los Precios',
    'sort_by' => 'Ordenar Por',
    'best_selling' => 'Más Vendidos',
    'top_rated' => 'Más Valorados',
    'newest' => 'Más Recientes',
    'refresh' => 'Actualizar',
    'booking_detail' => 'Detalle de la Reserva',
    'exp' => 'Exp',
    'applied' => 'Aplicado',
    'current_location' => 'Ubicación Actual',
    'record_not_found' => 'Registro No Encontrado',
    'get_nearest_services' => 'Obtener Servicios Más Cercanos',
    'continue_view_services' => '¿Continuar viendo los servicios disponibles de TODAS las áreas?',
    'discover_find_services' => 'Descubre y encuentra servicios disponibles en tu área actual.',
    'off_location' => 'Fuera de la Ubicación',
    'post_job_service' => 'Servicio de Publicación de Trabajo',
    'add_your_service' => 'Agregar Tu Servicio',
    'add_service_page_msg' => 'Agrega ese servicio que no puedes encontrar en nuestros servicios.',
    'Service_Category' => 'Categoría del Servicio',
    'select_category' => 'Selecciona una categoría',
    'loading_categories' => 'Cargando categorías',
    'service_name' => 'Nombre del Servicio',
    'Type' => 'Tipo',
    'advance_payment_option' => 'Opción de Pago Anticipado',
    'Proceed_To_Payment' => 'Proceder al Pago',
    'min' => 'Min',
    'services_booked' => 'Servicios Reservados',
    'subscribe_msg' => 'Gracias por suscribirte',
    'pay_now' => 'Pagar Ahora',
    'our_clients' => 'Nuestros Clientes',
    'hrs' => 'hrs',
    'reset' => 'Reiniciar',
    'cancel_booking' => 'Cancelar Reserva',
    'payment_option' => 'Opción de Pago',
    'include_package' => 'Incluido en Este Paquete',
    'start' => 'Comenzar',
    'hold' => 'Mantener',
    'done' => 'Hecho',
    'resume' => 'Reanudar',
    'cancel' => 'Cancelar',
    'reason' => 'Motivo',
    'waiting_for_response' => 'Esperando Respuesta',
    'reason_modal_msg' => '¿Estás seguro de que deseas mantener este servicio?',
    'cancel_modal_msg' => 'Por favor, da una razón para cancelar esta reserva',
    'job_request' => 'Solicitud de Trabajo',
    'near_by_location' => 'Ubicación Cercana',
    'handyman_category' => 'Categoría de Manitas',
    'popular_services' => 'Servicios Populares',
    'terms_conditions' => 'Términos y Condiciones',
    'privacy_policy' => 'Política de Privacidad',
    'accept_all' => '¡Aceptar Todo!',
    'reviews_for' => 'Opiniones Para',
    'min_read' => 'Lectura Min',
    'available_days' => 'Días Disponibles',
    'available_location' => 'Ubicación Disponible',
    'all' => 'Todos',
    'view_more' => 'Ver Más',
    'location' => 'Ubicación',
    'slot_not_available' => 'Ranura no disponible',
    'get_current_location' => 'Obtener ubicación actual',
    'data_deletion_request' => 'Deletation Request',
    'admin_login'=>'Admin Login',
];
